/****************************************************************************
 Include Section
*****************************************************************************/

#include "global.h"

/*****************************************************************************
 Symbolic constants / definitions
******************************************************************************/

#define LED1            Px6
#define LED2            Px7
#define LED3            Px8
#define LED4            Px9
#define LED5            Px10
#define LED6            Px11
#define SETUP_LED       LED1 | LED2 | LED3 | LED4 | LED5 | LED6
#define ALL_LED         SETUP_LED

#define LED_PORT_MODE   PORTG_FER
#define LED_OUTPUT_SET  PORTG_DIR_SET
#define LED_INPUT_SET   PORTG_DIR_CLEAR
#define LED_TURN_ON     PORTG_SET
#define LED_TURN_OFF    PORTG_CLEAR
#define LED_STATUS      PORTG

/* for __led_toogle */
#define LED_TOGGLE      LED6
#define LED_SPEED       0x1DCD6500  /* 0x1DCD6500 = ~1Hz LED frequency @ 500MHz CCLK */
                                    /* alternativ: use function _GetCCLK to run 1Hz */

/*****************************************************************************
 Global Variables
******************************************************************************/

//.GLOBAL b2_LED1_STATUS;
//.GLOBAL b2_LED2_STATUS;
//.GLOBAL b2_LED3_STATUS;
//.GLOBAL b2_LED4_STATUS;
//.GLOBAL b2_LED5_STATUS;
//.GLOBAL b2_LED6_STATUS;
//.GLOBAL b2_ALL_LED_STATUS;

/*****************************************************************************
 Variables
******************************************************************************/
.SECTION L1_data;

.BYTE2 b2_LED1_STATUS;
.BYTE2 b2_LED2_STATUS;
.BYTE2 b2_LED3_STATUS;
.BYTE2 b2_LED4_STATUS;
.BYTE2 b2_LED5_STATUS;
.BYTE2 b2_LED6_STATUS;
.BYTE2 b2_ALL_LED_STATUS;

/*****************************************************************************
 Functions
******************************************************************************/

.SECTION L1_code;

/*****************************************************************************
 Prototypes
******************************************************************************/

.GLOBAL __led_setup;
.GLOBAL __led1_toogle;
.GLOBAL __led2_toogle;
.GLOBAL __led3_toogle;
.GLOBAL __led4_toogle;
.GLOBAL __led5_toogle;
.GLOBAL __led6_toogle;
.GLOBAL __led_toogle;


/****************************************************************************
 Function:              __led_setup
 Description:           Set up GP Port G for LED use
 Input Parameters:      none
 Return Parameters:     none
 Registers Used:        R7:6,P5:4
 Global Registers Used: none
 Global Variables Used: none
 C-Callable :           no
*****************************************************************************/

__led_setup:

    link 0;
    [--SP] = ASTAT;
    [--SP] = (R7:6,P5:4);
    IMM32(P5,SYS_MMR_BASE);

    R6 = SETUP_LED;

    /* Setup GPIO port for LEDs to GPIO mode. */
    /* Leaves all other signals as they are. */
    R6 = ~R6;
    R7 = w[P5] (z);
    R7 = R6 & R7;
    w[P5 + lo(LED_PORT_MODE)] = R7;

    /* Turn all LEDs off initially once GPIO pins are enabled as outputs */
    R6 = ~R6;
    w[P5 + lo(LED_TURN_OFF)] = R6;

    /* Setup GPIO pins for LEDs to output mode */
    /* Leaves the remaining output modes as they are. */
    R7 = w[P5 + lo(LED_OUTPUT_SET)] (z);
    R7 = R6 | R7;
    w[P5 + lo(LED_OUTPUT_SET)] = R7;


    /* check LEDx status for LEDx toggle operation and store in b2_LEDx_STATUS */
    R7 = w[P5 + lo(LED_STATUS)];
    R6 = LED1;
    R6 = R7 & R6;
    IMM32(P4,b2_LED1_STATUS);
    w[P4] = R6;
    
    R6 = LED2;
    R6 = R7 & R6;
    IMM32(P4,b2_LED2_STATUS);
    w[P4] = R6;

    R6 = LED3;
    R6 = R7 & R6;
    IMM32(P4,b2_LED3_STATUS);
    w[P4] = R6;

    R6 = LED4;
    R6 = R7 & R6;
    IMM32(P4,b2_LED4_STATUS);
    w[P4] = R6;

    R6 = LED5;
    R6 = R7 & R6;
    IMM32(P4,b2_LED5_STATUS);
    w[P4] = R6;

    R6 = LED6;
    R6 = R7 & R6;
    IMM32(P4,b2_LED6_STATUS);
    w[P4] = R6;

    R6 = ALL_LED;
    R6 = R7 & R6;
    IMM32(P4,b2_ALL_LED_STATUS);
    w[P4] = R6;


    (R7:6,P5:4) = [SP++];
    ASTAT = [SP++];
    unlink;

    rts;
__led_setup.end:


/****************************************************************************
 Function:              __led1_toogle
 Description:           Perform LED1 toggle operation
                        System MMR write accesses only to save cycle time
                        LED off assumed at the beginning
 Input Parameters:      none
 Return Parameters:     none
 Registers Used:        R7:6,P5:4
 Global Registers Used: none
 Global Variables Used: none
 C-Callable :           no
*****************************************************************************/

__led1_toogle:

    link 0;
    [--SP] = ASTAT;
    [--SP] = (R7:6,P5:4);
    IMM32(P5,SYS_MMR_BASE);


    IMM32(P4,b2_LED1_STATUS);
    R7 = w[P4];
    w[P5 + lo(LED_TURN_OFF)] = R7;
    R6 = LED1;
    R7 = R7 ^ R6;
    w[P5 + lo(LED_TURN_ON)] = R7;
    w[P4] = R7;


    __led1_toogle.all_done:
    (R7:6,P5:4) = [SP++];
    ASTAT = [SP++];
    unlink;

    rts;
__led1_toogle.end:


/****************************************************************************
 Function:              __led2_toogle
 Description:           Perform LED2 toggle operation
                        System MMR write accesses only to save cycle time
                        LED off assumed at the beginning
 Input Parameters:      none
 Return Parameters:     none
 Registers Used:        R7:6,P5:4
 Global Registers Used: none
 Global Variables Used: none
 C-Callable :           no
*****************************************************************************/

__led2_toogle:

    link 0;
    [--SP] = ASTAT;
    [--SP] = (R7:6,P5:4);
    IMM32(P5,SYS_MMR_BASE);


    IMM32(P4,b2_LED2_STATUS);
    R7 = w[P4];
    w[P5 + lo(LED_TURN_OFF)] = R7;
    R6 = LED2;
    R7 = R7 ^ R6;
    w[P5 + lo(LED_TURN_ON)] = R7;
    w[P4] = R7;


    __led2_toogle.all_done:
    (R7:6,P5:4) = [SP++];
    ASTAT = [SP++];
    unlink;

    rts;
__led2_toogle.end:


/****************************************************************************
 Function:              __led3_toogle
 Description:           Perform LED3 toggle operation
                        System MMR write accesses only to save cycle time
                        LED off assumed at the beginning
 Input Parameters:      none
 Return Parameters:     none
 Registers Used:        R7:6,P5:4
 Global Registers Used: none
 Global Variables Used: none
 C-Callable :           no
*****************************************************************************/

__led3_toogle:

    link 0;
    [--SP] = ASTAT;
    [--SP] = (R7:6,P5:4);
    IMM32(P5,SYS_MMR_BASE);


    IMM32(P4,b2_LED3_STATUS);
    R7 = w[P4];
    w[P5 + lo(LED_TURN_OFF)] = R7;
    R6 = LED3;
    R7 = R7 ^ R6;
    w[P5 + lo(LED_TURN_ON)] = R7;
    w[P4] = R7;


    __led3_toogle.all_done:
    (R7:6,P5:4) = [SP++];
    ASTAT = [SP++];
    unlink;

    rts;
__led3_toogle.end:


/****************************************************************************
 Function:              __led4_toogle
 Description:           Perform LED4 toggle operation
                        System MMR write accesses only to save cycle time
                        LED off assumed at the beginning
 Input Parameters:      none
 Return Parameters:     none
 Registers Used:        R7:6,P5:4
 Global Registers Used: none
 Global Variables Used: none
 C-Callable :           no
*****************************************************************************/

__led4_toogle:

    link 0;
    [--SP] = ASTAT;
    [--SP] = (R7:6,P5:4);
    IMM32(P5,SYS_MMR_BASE);


    IMM32(P4,b2_LED4_STATUS);
    R7 = w[P4];
    w[P5 + lo(LED_TURN_OFF)] = R7;
    R6 = LED4;
    R7 = R7 ^ R6;
    w[P5 + lo(LED_TURN_ON)] = R7;
    w[P4] = R7;


    __led4_toogle.all_done:
    (R7:6,P5:4) = [SP++];
    ASTAT = [SP++];
    unlink;

    rts;
__led4_toogle.end:


/****************************************************************************
 Function:              __led5_toogle
 Description:           Perform LED5 toggle operation
                        System MMR write accesses only to save cycle time
                        LED off assumed at the beginning
 Input Parameters:      none
 Return Parameters:     none
 Registers Used:        R7:6,P5:4
 Global Registers Used: none
 Global Variables Used: none
 C-Callable :           no
*****************************************************************************/

__led5_toogle:

    link 0;
    [--SP] = ASTAT;
    [--SP] = (R7:6,P5:4);
    IMM32(P5,SYS_MMR_BASE);


    IMM32(P4,b2_LED5_STATUS);
    R7 = w[P4];
    w[P5 + lo(LED_TURN_OFF)] = R7;
    R6 = LED5;
    R7 = R7 ^ R6;
    w[P5 + lo(LED_TURN_ON)] = R7;
    w[P4] = R7;


    __led5_toogle.all_done:
    (R7:6,P5:4) = [SP++];
    ASTAT = [SP++];
    unlink;

    rts;
__led5_toogle.end:


/****************************************************************************
 Function:              __led6_toogle
 Description:           Perform LED6 toggle operation
                        System MMR write accesses only to save cycle time
                        LED off assumed at the beginning
 Input Parameters:      none
 Return Parameters:     none
 Registers Used:        R7:6,P5:4
 Global Registers Used: none
 Global Variables Used: none
 C-Callable :           no
*****************************************************************************/

__led6_toogle:

    link 0;
    [--SP] = ASTAT;
    [--SP] = (R7:6,P5:4);
    IMM32(P5,SYS_MMR_BASE);


    IMM32(P4,b2_LED6_STATUS);
    R7 = w[P4];
    w[P5 + lo(LED_TURN_OFF)] = R7;
    R6 = LED6;
    R7 = R7 ^ R6;
    w[P5 + lo(LED_TURN_ON)] = R7;
    w[P4] = R7;


    __led6_toogle.all_done:
    (R7:6,P5:4) = [SP++];
    ASTAT = [SP++];
    unlink;

    rts;
__led6_toogle.end:


/****************************************************************************
 Function:              __led_toogle
 Description:           Perform LED toggle operation inside an infinite loop
 Input Parameters:      none
 Return Parameters:     none
 Registers Used:        R7,P5:4
 Global Registers Used: none
 Global Variables Used: none
 C-Callable :           no
*****************************************************************************/

__led_toogle:

    link 0;
    [--SP] = ASTAT;
    [--SP] = (R7:7,P5:4);
    IMM32(P5,SYS_MMR_BASE);


    /* Set up the loop counter duration */
//    IMM32(P4,LED_SPEED);
    call __get_cclk_hz;
    P4 = R0;
    nop;nop;nop;nop;

    /* R7 should contain a list of the LEDs that you wish to toggle in the infinite loop */
    R7 = LED_TOGGLE;

    /* The infinite loop that toggles the LEDs */
    _infinite_loop:

        /* Initialize the two hardware loop counters */
        lsetup(_led_on,  _led_on)  LC0 = P4;
        lsetup(_led_off, _led_off) LC1 = P4;
        /* Turn off the EZ-KIT LEDs then enter loop */
        w[P5 + lo(LED_TURN_ON)] = R7;
        _led_on: nop;
        /* Turn on the EZ-KIT LEDs then enter loop */
        w[P5 + lo(LED_TURN_OFF)] = R7;
        _led_off: nop;

        jump _infinite_loop;

    _infinite_loop.end:


    (R7:7,P5:4) = [SP++];
    ASTAT = [SP++];
    unlink;

    rts;
__led_toogle.end:


/*****************************************************************************
 EOF
******************************************************************************/
