/********************************************************************************
 System Setup Define Section
 
 Comment out (please don't delete) the ones that do not apply to your code
********************************************************************************/


/*****************************************************************************
 Symbolic constants / definitions
******************************************************************************/


/****************************************************************************************
* The following option is always required, if SDRAM memory is required:                 *
*           #define SDRAM_SIZE xy       Available options for xy are:                   *
*                                       128 --> SDRAM memory size = 128MB               *
*                                       64 --> SDRAM memory size = 64MB                 *
*                                       32 --> SDRAM memory size = 32MB                 *
*           #define EN_SDRAM            --> Enable SDR-SDRAM memory or DDR-SDRAM        *
*                                       usually NOT required                            *
*                                       either VDSP++/Emulator is doing                 *
*                                       these settings or init code                     *
*           #define EN_ASYNC_MEM        --> Enable asynchronous memory                  *
*           #define SET_PLL             --> Change default (reset) PLL and              *
*                                       voltage controller settings                     *
****************************************************************************************/

#define             SDRAM_SIZE      64
//#define             EN_SDRAM

//#define             EN_ASYNC_MEM

#define             SET_PLL


/************************************************************
* Otherwise code is run in supervisor mode ISR15 by default *
************************************************************/

//#define             RUN_USER


/*******************************************************************************************************************
* Define which cache-setup to use.                                                                                 *
* Available options are:                                                                                           *
*          #define INSTR_CACHE_EN       --> enable instruction cache                                               *
*                                                                                                                  *
*          #define DATA_CACHE_EN        --> enable data cache                                                      *
*          #define DATA_CACHE_DCBS      --> DCBS = 1: A[23] is used to select Data Bank A or Data Bank B           *
*                                           only valid if DATA_CACHE_AB is defined                                 *
*                                           DCBS = 0: A[14] is used to select Data Bank A or Data Bank B (default) *
*          #define DATA_CACHE_AB        --> use both, Data Bank A+B for Data Cache                                 *
*                                           use Data Bank A only for Data Cache (default)                          *
*          #define DATA_CACHE_WT        --> CPLB_WT = 1: enable data-write-through                                 *
*                                           CPLB_WT = 0: enable data-write-back (default)                          *
*          #define DATA_CACHE_AOW       --> CPLB_L1_AOW = 1: Allocate cache lines on reads and writes              *
*                                           valid only if write through cacheable                                  *
*                                           CPLB_L1_AOW = 0: Allocate cache lines on reads only (default)          *
*******************************************************************************************************************/

//#define         INSTR_CACHE_EN          /* if enabling instruction cache, than comment out EN_SDRAM and use XML reset values */
                                        /* there are some functions placed into SDRAM memory */

//#define         DATA_CACHE_EN
#define         DATA_CACHE_DCBS
#define         DATA_CACHE_AB
#define         DATA_CACHE_WT
#define         DATA_CACHE_AOW


/********************************************************************************************
* Define the clock speed you want to boot with.                                             *
* Available options are:                                                                    *
*           #define INCLUDE_FILE        --> The ldr file you want to boot                   *
*           #define PFHW                --> GPIO input pin for incoming hostwait signal     *
*           #define FSCL_kHz            --> TWI clock. Range: ~20kHz - 400kHz               *
*           #define FSPICLK_Hz          --> SPI clock. Range: up to 33.25MHz @ 133MHz SLCK  *
*           #define PFSSEL              --> GPIO output pin for SPI slave select signal     *
*           #define UART_BIT_RATE       --> UART Bit Rate                                   *
*                                           1200,2400,4800,9600,19200,38400,56000,57600     *
*           #define HW_FLOW_CTL         --> UART Slave Boot Mode:                           *
*                                           activate Hardware Flow Control                  *
*                                           in UARTx_MCR register                           *
*                                           necessary if UART DMA transfer is used          *
*           #define EVAL_HWAIT          --> UART Slave Boot Mode: enable evaluation of the  *
*                                           host wait signal generated by slave device      *
********************************************************************************************/

//#define         INCLUDE_FILE        "./ldr/ezkitBF548_examples_8-bit-include_INIT-MOD.ldr"
//#define         INCLUDE_FILE        "./ldr/ezkitBF548_examples_8-bit-include_INIT-MOD_D.ldr"
//#define         INCLUDE_FILE        "./ldr/ezkitBF548_examples_8-bit-include_INIT-MOD_UART-D.ldr"
//#define         INCLUDE_FILE        "./ldr/ezkitBF548_examples_8-bit-include_INIT-MOD_D+UART-D.ldr"

//#define         INCLUDE_FILE        "./ldr/ezkitBF548_examples_8-bit-include.ldr"
//#define         INCLUDE_FILE        "./ldr/ezkitBF548_examples_8-bit-include_BIG.ldr"
#define         INCLUDE_FILE        "./ldr/ezkitBF548_examples_asm.ldr"

//#define         PFHW                PE11     /* PE11_PPI1CLK */
#define         PFHW                PE13     /* PE11_PPI1FS2 */

#define         FSCL_kHz            400

#define         FSPI0CLK_Hz         10000000
#define         PFSSEL              PE12     /* PE12_PPIFS1 */

#define         UART_BIT_RATE       57600
#define         HW_FLOW_CTL
//#define         EVAL_HWAIT


/*****************************************************************************
 EOF
******************************************************************************/
