/********************************************************************************************
 Additional masks and macro definitions that are missed in 'defBF54x_base.h' or 'defBF548.h'
 to allow the programmer to use symbolic names for register-access and bit-manipulation 
********************************************************************************************/

#if __VISUALDSPVERSION__ <= 0x05000300


/* ********************* PLL AND RESET MASKS ************************ */
/* SYSCR Masks */

#undef BMODE
#undef NOBOOT

#define BMODE           0x000F          /* Boot Mode - Latched During HW Reset From Mode Pins */
#define NOBOOT          0x0030          /* Execute From L1 or ASYNC Bank 0 When BMODE = 0 */


/* **************************  DMA CONTROLLER MASKS  ********************************/
/* DMAx_CONFIG, MDMA_yy_CONFIG Masks                                                */
#undef SET_NDSIZE
#define SET_NDSIZE(x)   ((x&0xF)<<8)    /* NDSIZE[3:0] (Flex Descriptor Size)
                                            Size of next descriptor
                                            0000 - Required if in Stop or Autobuffer mode
                                            0001 - 1001 - Descriptor size
                                            1010 - 1111 - Reserved */



/* *************  SYSTEM INTERRUPT CONTROLLER MASKS *************************************/
/* Peripheral Masks For SIC_ISR, SIC_IWR, SIC_IMASK                                     */

/* SIC_IARx Masks */
/* x = 0 to 9 */

#define PIVG(PNr, IVGNr) ( (IVGNr) - 7) << ( ((PNr)%8) * 4) /* Peripheral #PNr assigned IVG #IVGNr  */
/* Rx.L = lo(PIVG(62,10)); */
/* Rx.H = hi(PIVG(62,10)); */
/* PNr = 0 to 95 */
/* IVGNr = 7 to 15 */


/*  ********************  TWO-WIRE INTERFACE (TWI) MASKS  ***********************/

/* Bit macros for TWIx_CONTROL */
#define SET_TWI_PRESCALE(x)     ( (x) & PRESCALE )
#define SET_TWI_DCNT(x)         ( ((x) << 0x6) & DCNT )

/* Bit masks for TWIx_INT_MASK */
#define SCLIM       0x8000      /* Serial Clock Interrupt */
#define nSCLIM      0x0
#define SDAIM       0x4000      /* Serial Data Interrupt */
#define nSDAIM      0x0

/* Bit masks for TWIx_INT_STAT */
#define SCLI        0x8000      /* Serial Clock Interrupt */
#define nSCLI       0x0
#define SDAI        0x4000      /* Serial Data Interrupt */
#define nSDAI       0x0

/* Bit macros for TWIx_MASTER_ADDR */
#define SET_TWI_ADDR(x)         ( (x) & 0x7F )


/* ***********  SERIAL PERIPHERAL INTERFACE (SPI) MASKS  ****************************/

/* Bit masks for SPIx_CTL */
#define RDBR_CORE   0x0000      /* RDBR Read Initiates, IRQ when RDBR Full */
#define TDBR_CORE   0x0001      /* TDBR Write Initiates, IRQ when TDBR Empty */
#define RDBR_DMA    0x0002      /* DMA Read, DMA Until FIFO Empty */
#define TDBR_DMA    0x0003      /* DMA Write, DMA Until FIFO Full */


/* ************* SYSTEM INTERRUPT CONTROLLER MASKS ***************** */
/* SIC_IMASKx Masks */
/* masks are 32 bit wide, so two writes reguired for "64 bit" wide registers */
#define SIC_UNMASK_ALL          0x00000000          /* Unmask all peripheral interrupts */
#define SIC_MASK_ALL            0xFFFFFFFF          /* Mask all peripheral interrupts */
/* SIC_IMASKx Macros */
#define SIC_MASK(x)             (1 << (x))          /* Mask Peripheral #x interrupt */
#define SIC_UNMASK(x)           (0xFFFFFFFF ^ (1 << (x))) /* Unmask Peripheral #x interrupt */

/* SIC_IWR Masks */
#define IWR_DISABLE_ALL         0x00000000          /* Wakeup Disable all peripherals */
#define IWR_ENABLE_ALL          0xFFFFFFFF          /* Wakeup Enable all peripherals */
/* SIC_IWR Macros */
/* x = pos 0 to 31, for 32-63 use value-32 */
#define IWR_ENABLE(x)           (1 << (x))          /* Wakeup Enable Peripheral #x */
#define IWR_DISABLE(x)          (0xFFFFFFFF ^ (1 << (x))) /* Wakeup Disable Peripheral #x */


/* ************** UART CONTROLLER MASKS *************************/
/* Bit masks for UART Divisor Latch Registers: UARTx_DLL & UARTx_DLH */
#define UARTDLL                 0x00FF              /* Divisor Latch Low Byte */
#define UARTDLH                 0xFF00              /* Divisor Latch High Byte */


#endif /* __VISUALDSPVERSION__ <= 0x05000300 */


/****************************************************************************
 EOF
*****************************************************************************/
